@@ -1,5 +1,7 @@
 from reinvent_scoring.scoring.enums.component_specific_parameters_enum import ComponentSpecificParametersEnum
+from reinvent_scoring.scoring.enums.container_type_enum import ContainerType
 from reinvent_scoring.scoring.enums.descriptor_types_enum import DescriptorTypesEnum
+from reinvent_scoring.scoring.enums.environmental_variables_enum import EnvironmentalVariablesEnum
 from reinvent_scoring.scoring.enums.logging_mode_enum import LoggingModeEnum
 from reinvent_scoring.scoring.enums.rocs_input_file_types_enum import ROCSInputFileTypesEnum
 from reinvent_scoring.scoring.enums.rocs_similarity_measures_enum import ROCSSimilarityMeasuresEnum
