@@ -6,10 +6,11 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     RocsSimilarity, ParallelRocsSimilarity, PredictivePropertyComponent, SelectivityComponent, \
     SASComponent, MolWeight, PSA, RotatableBonds, HBD_Lipinski, HBA_Lipinski, \
     NumRings, AZlogD74, HLMClint, SlogP, \
-    RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, CACO2EffluxPiP, AZlogD74PiP, \
-    CACO2IntrinsicPiP, HHClintPiP, HLMClintPiP, RHClintPiP, SolubilityDDPiP, HERGPiP, RatPKPiP, Top20
+    RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20
 from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.enums import ScoringFunctionComponentNameEnum
+from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
+from reinvent_scoring.scoring.score_components.pip.pip_prediction_component import PiPPredictionComponent
 
 
 class ScoreComponentFactory:
@@ -46,16 +47,17 @@ class ScoreComponentFactory:
             enum.SELECTIVITY: SelectivityComponent,
             enum.SA_SCORE: SASComponent,
             enum.AZDOCK: AZdock,
-            enum.AZ_LOGD74_PIP: AZlogD74PiP,
-            enum.CACO2_INTR_PIP: CACO2IntrinsicPiP,
-            enum.CACO2_EFFLUX_PIP: CACO2EffluxPiP,
-            enum.HH_CLINT_PIP: HHClintPiP,
-            enum.HLM_CLINT_PIP: HLMClintPiP,
-            enum.RH_CLINT_PIP: RHClintPiP,
-            enum.SOLUBILITY_DD_PIP: SolubilityDDPiP,
-            enum.HERG_PIP: HERGPiP,
+            enum.AZ_LOGD74_PIP: PiPPredictionComponent,
+            enum.CACO2_INTR_PIP: PiPPredictionComponent,
+            enum.CACO2_EFFLUX_PIP: PiPLogPredictionComponent,
+            enum.HH_CLINT_PIP: PiPLogPredictionComponent,
+            enum.HLM_CLINT_PIP: PiPLogPredictionComponent,
+            enum.RH_CLINT_PIP: PiPLogPredictionComponent,
+            enum.SOLUBILITY_DD_PIP: PiPLogPredictionComponent,
+            enum.HERG_PIP: PiPPredictionComponent,
             enum.RAT_PK_PIP: RatPKPiP,
-            enum.CLAB_TOP_20: Top20
+            enum.CLAB_TOP_20: Top20,
+            enum.RA_SCORE: PiPPredictionComponent
         }
         return component_map
 
